/****************************************************************************
** Meta object code from reading C++ file 'osdaction.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kscreen-6.7.4/common/osdaction.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'osdaction.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KScreen9OsdActionE_t {};
} // unnamed namespace

template <> constexpr inline auto KScreen::OsdAction::qt_create_metaobjectdata<qt_meta_tag_ZN7KScreen9OsdActionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KScreen::OsdAction",
        "label",
        "iconName",
        "action",
        "Action",
        "NoAction",
        "SwitchToExternal",
        "SwitchToInternal",
        "Clone",
        "ExtendLeft",
        "ExtendRight"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'label'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iconName'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'action'
        QtMocHelpers::PropertyData<enum Action>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Action'
        QtMocHelpers::EnumData<enum Action>(4, 4, QMC::EnumFlags{}).add({
            {    5, Action::NoAction },
            {    6, Action::SwitchToExternal },
            {    7, Action::SwitchToInternal },
            {    8, Action::Clone },
            {    9, Action::ExtendLeft },
            {   10, Action::ExtendRight },
        }),
    };
    return QtMocHelpers::metaObjectData<OsdAction, qt_meta_tag_ZN7KScreen9OsdActionE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KScreen::OsdAction::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KScreen9OsdActionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KScreen9OsdActionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KScreen9OsdActionE_t>.metaTypes,
    nullptr
} };

void KScreen::OsdAction::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<OsdAction *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->label; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->iconName; break;
        case 2: *reinterpret_cast<enum Action*>(_v) = _t->action; break;
        default: break;
        }
    }
}
QT_WARNING_POP
